Operators
=========


Inventory Operators
-------------------

.. autofunction:: emiproc.inventories.utils.add_inventories

.. autofunction:: emiproc.inventories.utils.combine_inventories

.. autofunction:: emiproc.inventories.utils.scale_inventory

.. autofunction:: emiproc.inventories.utils.get_total_emissions

.. autofunction:: emiproc.inventories.utils.drop


Geometric Transformations 
-------------------------

.. autofunction:: emiproc.inventories.utils.crop_with_shape


.. autofunction:: emiproc.regrid.remap_inventory